==> nextcloud-25.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/eo.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Rondoj",
    "Circles' files" : "Dosieroj de la rondoj",
    "Select circles to filter by" : "Elekti rondojn per kiu filtri",
    "No circles found" : "Neniu rondo trovita",
    "Please select circles to filter by" : "Nv. elekti rondojn per kiu filtri",
    "No files found for the selected circles" : "Neniu dosiero trovita kun la elektitaj rondoj",
    "You created the circle {circle}" : "Vi kreis la rondon {circle}",
    "{author} created the circle {circle}" : "{author} kreis la rondon {circle}",
    "You deleted {circle}" : "Vi forigis la rondon {circle}",
    "{author} deleted {circle}" : "{author} forigis la rondon {circle}",
    "You linked {group} to {circle}" : "Vi ligis grupon {group} al rondo {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} estis ligita al rondo {circle} de {author}",
    "You unlinked {group} from {circle}" : "Vi malligis grupon {group} el rondo {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} estis malligita el rondo {circle} de {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Vi ŝanĝis la nivelon de la ligita grupo {group} en rondo {circle} al %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} ŝanĝis la nivelon de la ligita grupo {group} en rondo {circle} al %1$s",
    "You sent a request to link {circle} with {remote}" : "Vi sendis peton por ligi rondon {circle} kun {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} sendis peton por ligi rondon {circle} kun {remote}",
    "{remote} requested a link with {circle}" : "{remote} petis ligilon kun rondo {circle}",
    "The request to link {circle} with {remote} has been rejected" : "La peto ligi rondon {circle} kun {remote} estis malakceptita",
    "The request to link {remote} with {circle} has been canceled remotely" : "La peto ligi rondon {circle} kun {remote} estis fore nuligita",
    "The request to link {circle} with {remote} has been accepted" : "La peto ligi rondon {circle} kun {remote} estis akceptita",
    "You dismissed the request to link {remote} with {circle}" : "Vi rifuzis peton por ligi {remote} kun rondo {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} rifuzis peton por ligi {remote} kun rondo {circle}",
    "You canceled the request to link {circle} with {remote}" : "Vi nuligis peton por ligi rondon {circle} kun {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} nuligis peton por ligi rondon {circle} kun {remote}",
    "You accepted the request to link {remote} with {circle}" : "Vi akceptis peton por ligi {remote} kun rondo {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} akceptis peton por ligi {remote} kun rondo {circle}",
    "A link between {circle} and {remote} is now up and running" : "Ligilo inter {circle} kaj {remote} estas unu funkcianta",
    "The link between {circle} and {remote} has been shutdown remotely" : "La ligilo inter {circle} kaj {remote} estis fore fermita",
    "You closed the link between {circle} and {remote}" : "Vi fermis la ligilon inter {circle} kaj {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} fermis la ligilon inter {circle} kaj {remote}",
    "You joined {circle}" : "Vi membriĝis al {circle}",
    "{member} joined {circle}" : "{member} membriĝis al {circle}",
    "You accepted the invitation to join {circle}" : "Vi akceptis inviton membriĝi al {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} akceptis inviton membriĝi al {circle}",
    "You added {member} as member to {circle}" : "Vi aldonis {member} kiel membron de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} aldonis vin kiel membron de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} aldonis {member} kiel membron de {circle}",
    "You added {external} to {circle}" : "Vi aldonis {external} al {circle}",
    "{external} has been added to {circle} by {author}" : "{author} aldonis membron {external} al {circle}",
    "You accepted {member}'s request to join {circle}" : "Vi akceptis peton de {member} por membriĝi al {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} akceptis vian peton por membriĝi al {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} akceptis peton de {member} por membriĝi al {circle}",
    "You left {circle}" : "Vi forlasis rondon {circle}",
    "{member} left {circle}" : "{member} forlasis rondon {circle}",
    "You declined the invitation to join {circle}" : "Vi rifuzis inviton membriĝi al {circle}",
    "{member} declined an invitation to join {circle}" : "{member} rifuzis inviton membriĝi al {circle}",
    "You cancelled your request to join {circle}" : "Vi nuligis peton por membriĝi al {circle}",
    "{member} cancelled his request to join {circle}" : "{member} nuligis sian peton por membriĝi al {circle}",
    "You removed {member} from {circle}" : "Vi forigis {member} el {circle}",
    "You have been removed from {circle} by {author}" : "{author} forigis vin el {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} forigis membron {member} el {circle}",
    "You removed {external} from {circle}" : "Vi forigis {external} el {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} forigis {external} el {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Vi nuligis inviton de {member} membriĝi al {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} nuligis vian inviton membriĝi al {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} nuligis inviton de {member} membriĝi al {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vi rifuzis peton de {member} membriĝi al {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Via peto membriĝi al {circle} estis rifuzita de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Peto de {member} membriĝi al {circle} estis rifuzita de {author}",
    "You invited {member} to join {circle}" : "Vi invitis {member} membriĝi al {circle}",
    "You have been invited to join {circle} by {author}" : "{author} invitis vin membriĝi al {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} invitis membron {member} membriĝi al {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Vi ŝanĝis nivelon de {member} en {circle} al %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ŝanĝis vian nivelon en {circle} al %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ŝanĝis nivelon de {member} en {circle} al %1$s",
    "You sent a request to join {circle}" : "Vi sendis peton por membriĝi al {circle}",
    "{member} sent a request to join {circle}" : "{member} sendis peton por membriĝi al {circle}",
    "You are the new owner of {circle}" : "Vi nun estas la nova posedanto de {circle}",
    "{member} is the new owner of {circle}" : "{member} nun estas la nova posedanto de {circle}",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Pri grava evento en <strong>rondo</strong> kiun vi kontrolas",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Visible" : "Videbla",
    "Open" : "Malfermi",
    "Hidden" : "Nevidebla",
    "Local" : "Loka",
    "Root" : "Radiko",
    "Federated" : "Federated",
    "Contact" : "Kontakto",
    "Circle" : "Rondo",
    "Member" : "Membro",
    "Moderator" : "Kontrolanto",
    "Admin" : "Administranto",
    "Owner" : "Posedanto",
    "%s shared »%s« with you." : "%s kunhavigis „%s“ kun vi.",
    "%s on %s" : "%s el %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
    "Open »%s«" : "Malfermi „%s“",
    "Circle not found" : "Rondo ne trovita",
    "A circle with that name exists" : "Rondo kun sama nomo jam ekzistas",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Vi ne povas uzi la aplikaĵon „Rondoj“, ĝis via administranto permesas almenaŭ unu tipon de rondoj.",
    "This member does not exist" : "Tiu ĉi membro ne ekzistas",
    "Federated link not found" : "Federa ligilo ne trovita",
    "This feature is not available for personal circles" : "Tiu funkcio ne disponeblas por persona rondo",
    "The circle is not federated" : "La rondo ne estas federita",
    "You cannot join this circle" : "Vi ne povas membriĝi al tiu ĉi rondo",
    "This member is not a moderator" : "Tiu ĉi membro ne estas kontrolanto",
    "Insufficient privileges" : "Nesufiĉaj rajtoj",
    "This member is the owner of the circle" : "Tiu ĉi membro estas la posedanto de tiu ĉi rondo",
    "Level cannot be changed for this type of member" : "Nivelo ne ŝanĝeblas por tiu tipo de membro",
    "You are already a member of this circle" : "Vi jam estas membro de tiu ĉi rondo",
    "You have been blocked from this circle" : "Vi estis barita el tiu ĉi rondo",
    "Accept" : "Akcepti",
    "%s" : "%s",
    "Personal Circle" : "Persona rondo",
    "You need a specify a type of circle" : "Vi bezonas indiki tipon de rondo",
    "This member is not the owner of the circle" : "Tiu ĉi membro ne estas la posedanto de la rondo",
    "This member is not an admin of the circle" : "Tiu ĉi membro ne estas administranto el la rondo",
    "This group does not exist" : "Tiu ci grupo ne ekzistas",
    "This group is already linked to the circle" : "Tiu ĉi grupo jam estas ligita al la rondo",
    "You cannot edit level in a personal circle" : "Vi ne povas modifi nivelon en persona rondo",
    "Group cannot be set as owner of a circle" : "Grupo ne povas esti posedanto de rondo",
    "now" : "nun",
    "Email format is not valid" : "Formo de retpoŝtadreso ne validas",
    "This contact is not available" : "Tiu kontakto ne disponeblas",
    "Could not find share" : "Ne eblis trovi kunhavon",
    "Bring cloud-users closer together." : "Pliproksimigi uzantojn kune.",
    "No files in here" : "Neniu dosiero ĉi tie",
    "No entries found in this folder" : "Neniu elemento en tiu ĉi dosierujo",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "This user is already a member of the circle" : "Tiu ĉi uzanto jam estas membro el tiu rondo",
    "The user is already a member of this circle" : "La uzanto jam estas membro de tiu ĉi rondo",
    "The user has already been invited into this circle" : "La uzanto jam estis invitita al tiu ĉi rondo",
    "This user does not exist" : "Tiu ĉi uzanto ne ekzistas"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/eo.js <==
OC.L10N.register(
    "circles",
    {
    "You deleted {circle}" : "Vi forigis la rondon {circle}",
    "{author} deleted {circle}" : "{author} forigis la rondon {circle}",
    "You removed {member} from {circle}" : "Vi forigis {member} el {circle}",
    "You joined {circle}" : "Vi membriĝis al {circle}",
    "{member} joined {circle}" : "{member} membriĝis al {circle}",
    "You accepted the invitation to join {circle}" : "Vi akceptis inviton membriĝi al {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} akceptis inviton membriĝi al {circle}",
    "You added {member} as member to {circle}" : "Vi aldonis {member} kiel membron de {circle}",
    "You have been added as member to {circle} by {author}" : "{author} aldonis vin kiel membron de {circle}",
    "{member} has been added as member to {circle} by {author}" : "{author} aldonis {member} kiel membron de {circle}",
    "You added {external} to {circle}" : "Vi aldonis {external} al {circle}",
    "{external} has been added to {circle} by {author}" : "{author} aldonis membron {external} al {circle}",
    "You accepted {member}'s request to join {circle}" : "Vi akceptis peton de {member} por membriĝi al {circle}",
    "Your request to join {circle} has been accepted by {author}" : "{author} akceptis vian peton por membriĝi al {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} akceptis peton de {member} por membriĝi al {circle}",
    "You left {circle}" : "Vi forlasis rondon {circle}",
    "{member} left {circle}" : "{member} forlasis rondon {circle}",
    "You declined the invitation to join {circle}" : "Vi rifuzis inviton membriĝi al {circle}",
    "{member} declined an invitation to join {circle}" : "{member} rifuzis inviton membriĝi al {circle}",
    "You cancelled your request to join {circle}" : "Vi nuligis peton por membriĝi al {circle}",
    "You have been removed from {circle} by {author}" : "{author} forigis vin el {circle}",
    "{member} has been removed from {circle} by {author}" : "{author} forigis membron {member} el {circle}",
    "You removed {external} from {circle}" : "Vi forigis {external} el {circle}",
    "{external} has been removed from {circle} by {author}" : "{author} forigis {external} el {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Vi nuligis inviton de {member} membriĝi al {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} nuligis vian inviton membriĝi al {circle}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} nuligis inviton de {member} membriĝi al {circle}",
    "You dismissed {member}'s request to join {circle}" : "Vi rifuzis peton de {member} membriĝi al {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Via peto membriĝi al {circle} estis rifuzita de {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Peto de {member} membriĝi al {circle} estis rifuzita de {author}",
    "You invited {member} to join {circle}" : "Vi invitis {member} membriĝi al {circle}",
    "You have been invited to join {circle} by {author}" : "{author} invitis vin membriĝi al {circle}",
    "{member} has been invited to join {circle} by {author}" : "{author} invitis membron {member} membriĝi al {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "Vi ŝanĝis nivelon de {member} en {circle} al %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} ŝanĝis vian nivelon en {circle} al %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} ŝanĝis nivelon de {member} en {circle} al %1$s",
    "You sent a request to join {circle}" : "Vi sendis peton por membriĝi al {circle}",
    "{member} sent a request to join {circle}" : "{member} sendis peton por membriĝi al {circle}",
    "You are the new owner of {circle}" : "Vi nun estas la nova posedanto de {circle}",
    "{member} is the new owner of {circle}" : "{member} nun estas la nova posedanto de {circle}",
    "Personal" : "Persona",
    "System" : "Sistemo",
    "Visible" : "Videbla",
    "Open" : "Malfermi",
    "Password protected" : "Protektita per pasvorto",
    "Hidden" : "Nevidebla",
    "Local" : "Loka",
    "Root" : "Radiko",
    "Federated" : "Federated",
    "Email address" : "Retpoŝtadreso",
    "Contact" : "Kontakto",
    "Member" : "Membro",
    "Moderator" : "Kontrolanto",
    "Admin" : "Administranto",
    "Owner" : "Posedanto",
    "%s shared »%s« with you." : "%s kunhavigis „%s“ kun vi.",
    "%s on %s" : "%s el %s",
    "%1$s via %2$s" : "%1$s pere de %2$s",
    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
    "Open »%s«" : "Malfermi „%s“",
    "This feature is not available for personal circles" : "Tiu funkcio ne disponeblas por persona rondo",
    "This member is not a moderator" : "Tiu ĉi membro ne estas kontrolanto",
    "Insufficient privileges" : "Nesufiĉaj rajtoj",
    "This member does not exist" : "Tiu ĉi membro ne ekzistas",
    "Level cannot be changed for this type of member" : "Nivelo ne ŝanĝeblas por tiu tipo de membro",
    "You are already a member of this circle" : "Vi jam estas membro de tiu ĉi rondo",
    "You have been blocked from this circle" : "Vi estis barita el tiu ĉi rondo",
    "Accept" : "Akcepti",
    "%s" : "%s",
    "Open %s" : "Malfermi %s",
    "Bring cloud-users closer together." : "Pliproksimigi uzantojn kune.",
    "Loading…" : "Ŝargado...",
    "No files in here" : "Neniu dosiero ĉi tie",
    "No entries found in this folder" : "Neniu elemento en tiu ĉi dosierujo",
    "Name" : "Nomo",
    "Size" : "Grando",
    "Modified" : "Modifita",
    "Shared to Circles" : "Kunhavigita kun rondoj"
},
"nplurals=2; plural=(n != 1);");
